INTRODUCTION

This document discusses the topic of Environment variables in C68. It
covers how theya re set up, how they are accessed, and why you might
want to use them in the first place.


WHY USE ENVIRONMENT VARIABLES

Enviroment Variables are an idea that has been adopted from the UNIX
operating System. Environment variables are basically a facility that
you can set up when you first start a system to control certain aspects
of how your system will run. 

In QDOS terms, this means that you can set up information in your BOOT
file that can be later interogated by other programs running. This can
make it much easier to centalise the control of your system rather than
having to tell each program seperately as you run it.


SUPERBASIC INTERFACE

The SuperBasic interface is provided as four extensions to the
SuperBasic interpreter, the code for which in contained within the
ENV_BIN file provided with the standard distribution. This file should
be LRESPRed if you wish to make use of the facilities that it offers.

The four extensions provided are as follows:- 
 
SETENV -    A procedure that allows the setting of an
            environment variable 

ENV_LIST -  A procedure to output the environment
            variables to a channel (usually the screen)

ENV_DEL -   A procedure to delete an existing environment
            variable.

GETENV$ -   A function that returns the value of an
            environment variable. 

USING THE SUPERBASIC INTERFACE

SETENV "NAME=VALUE"

This sets up an environment variable NAME, and gives it the value
VALUE. For instance, the command
 
 SETENV "TMP=ram1_"
 
gives the environment variable TMP the value of ram1_. It is worth
noting that the VALUE part may be null, ie 
 
 SETENV "TMP=" 

will assign a null string to the variable TMP. This should be
contrasted with the putenv usage, below. Subsequently setting another
value for the same variable causes the previous definition to be
overwritten. Most users will set values at  startup from within their
boot files.


 ENV_LIST 
 or
 ENV_LIST #n


This causes all currently defined environment variables to be written
to the channel specified, or #1 by default.

 ENV_DEL "NAME"

This procedure will remove an environment variable definition
completely. In many cases this will be equivalent to using the SETENV
command to give a variable a null value.

 GETENV$("NAME")

In order to allow the environment variables to be manipulated from
SuperBasic, the GETNEV$ function will return the value of and
environment variable, or a null string if not found.  Hence, after

a$="test=debug level 1"
SETENV a$

PRINT GETENV("test") would print the string "debug level 1"

but

PRINT GETENV("TEST") would print a null string.

and the sequence 

b$ = GETENV$("TMP")
IF b$ = "" THEN 
 b$ = "RAM1_"
 SETENV "TMP=" & b$
ENDIF
SETENV "TMP_FILE=" & b$ & "WORK_TMP"

will ensure that the TMP variable is set, and that another
environmental variable, TMP_FILE, contains a reference to a file
WORK_TMP on the same device. 


C68 INTERFACE

The Environment Variables capability interface is built into all C68
programs that are compiled with Release 2.01 or later of C68.

The routine main() is now passed an additional parameter at program
startup that point the environement variables (if any) that are
currently set up. The syntax of main() is now therefore:

 int main (argc, argv, argp)
 int argc;
 char *argv[];
 char *env[];
 {
 ...

where the env variable is an array of string pointers. Each entry
points to a single NULL terminated string which is in the form:

 STRING=VALUE

and the list is terminated by a NULL pointer.

A user program has a number of library routines available to manipulate
environment variables:

 - the routine getenv() can be used to obtain the value of a specific
   named Environment Variable. A NULL pointer is returned if indicated
   Environment Variable does not exist or has no value. i.e.
  
  getenv("TEMP");

Would return a NULL if the TEMP Environment variable did not exists,
and a pointer to its value if it did. Please note that the returned
value may be a zero-length string. 

 - the routine putenv() can be used to give a value to an Environment
   variable. This will change the value if the named Environment Variable
   already exists, or create an new value if does not. Therefore a call of
   the form:

  putenv("TEMP=ram1_");

would set the environment variable TEMP to a value of ram1_.

If you want to remove an environment variable completely then call it
assigning a zero length value. i.e.

  putenv("NAME=");

 would delete the environement variable NAME.


INHERITING ENVIRONMENT VARIABLES

If a number of c68 compiled jobs are chained together then the
environment variables of each slave job are inherited from the ownerr.
The master job will obtain its values from the settings in SuperBasic.

This inheritance factor is important as it means that if a library call
is used to change one of the environment variables, then this is
remembered and passed on without changing the setting that is current
at the SuperBasic level.


STANDARD ENVIRONMENT VARIABLES

A number of standard Environment Variables are set up automatically by
the C68 system. These are

 PROG_USE
 DATA_USE
 SPL_USE

They contain the values for the Program, Data and Destination
directories respectively.


WHAT PROGRAMS USE ENVIRONMENT VARIABLES

To determine whether a program will use any environment variables, it
is necessary to look at the documentation for that program.

Programs that are supplied as part of the C68 system that DO make use
of Environment Variables are the CC, C68 and MAKE programs - refer to
the documentation on each program for the details.

AUTHOR(s)

Original version - Dave Nash.
C code modification - Dave Walker.
SuperBasic interface extension - Dave Woodman.
